@@ -1,3 +1,6 @@
 from .main import Map, Device
 from .read import read
 from .write import write
+
+__author__ = 'Jan Petykiewicz'
+__version__ = '0.5'
